@@ -1,9 +1,30 @@
 char tcl_tk707[] = "\
+#\n\
+#    This file is part of tk707.\n\
+#\n\
+#    Copyright (C) 2000, 2001, 2002, 2003, 2004 Chris Willing and Pierre Saramito \n\
+#\n\
+#    tk707 is free software; you can redistribute it and/or modify\n\
+#    it under the terms of the GNU General Public License as published by\n\
+#    the Free Software Foundation; either version 2 of the License, or\n\
+#    (at your option) any later version.\n\
+#\n\
+#    Foobar is distributed in the hope that it will be useful,\n\
+#    but WITHOUT ANY WARRANTY; without even the implied warranty of\n\
+#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n\
+#    GNU General Public License for more details.\n\
+#\n\
+#    You should have received a copy of the GNU General Public License\n\
+#    along with Foobar; if not, write to the Free Software\n\
+#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA\n\
+#\n\
+# ======================================================\n\
 #	File tk707.tcl\n\
 #	Remainder of gui, including key & mouse bindings. Then RUN!\n\
-\n\
-#	Pattern memory is now in C-land but track memory still in tcl/tk.\n\
 #\n\
+#	Pattern memory is now in C-land but track memory still in tcl/tk.\n\
+# ======================================================\n\
+\n\
 mem_init\n\
 \n\
 # ======================================================\n\
